@@ -296,7 +296,10 @@ class DynamoController(object):
         """ Execute the dynamo operation and return a proper response (success or error)"""
         try:
             if type == self.TYPE_GET:
-                d_res = self.table.get_item(Key=primary_keys, ProjectionExpression=columns_to_return)
+                params = {"Key": primary_keys}
+                if columns_to_return:
+                    params["ProjectionExpression"] = columns_to_return
+                d_res = self.table.get_item(**params)
                 if "Item" in d_res:
                     data = d_res["Item"]
                 else:
